@@ -1,12 +1,11 @@
 import datetime
 import uuid
-from typing import Dict, List, Optional, Set
+from typing import Optional
 
 from robotoff import settings
 from robotoff.insights.dataclass import InsightType
-from robotoff.models import Prediction, ProductInsight
+from robotoff.models import Prediction, ProductInsight, with_db
 from robotoff.off import get_server_type
-from robotoff.prediction.types import PredictionType
 from robotoff.products import (
     DBProductStore,
     get_image_id,
@@ -15,6 +14,7 @@ from robotoff.products import (
     is_nutrition_image,
     is_valid_image,
 )
+from robotoff.types import PredictionType
 from robotoff.utils import get_logger
 from robotoff.utils.types import JSONType
 
@@ -30,11 +30,12 @@ def generate_quality_facets():
     generate_fiber_quality_facet()
 
 
+@with_db
 def generate_fiber_quality_facet():
     product_store: DBProductStore = get_product_store()
     collection = product_store.collection
     added = 0
-    seen_set: Set[str] = set()
+    seen_set: set[str] = set()
 
     for prediction in (
         Prediction.select(Prediction.barcode, Prediction.source_image)
@@ -131,7 +132,7 @@ def generate_nutrition_image_insights():
     logger.info("{} insights deleted".format(deleted))
     product_store: DBProductStore = get_product_store()
     added = 0
-    seen_set: Set[str] = set()
+    seen_set: set[str] = set()
 
     prediction: Prediction
     for prediction in (
@@ -197,10 +198,10 @@ def generate_nutrition_image_insights():
     logger.info("Added: {}".format(added))
 
 
-def find_nutrition_image_lang(mentions: JSONType, min_count: int = 4) -> List[str]:
+def find_nutrition_image_lang(mentions: JSONType, min_count: int = 4) -> list[str]:
     nutrient_languages = find_nutrition_image_nutrient_languages(mentions)
 
-    lang_count: Dict[str, int] = {}
+    lang_count: dict[str, int] = {}
     for _, langs in nutrient_languages.items():
         for lang, count in langs.items():
             lang_count.setdefault(lang, 0)
@@ -211,10 +212,10 @@ def find_nutrition_image_lang(mentions: JSONType, min_count: int = 4) -> List[st
 
 def find_nutrition_image_nutrient_languages(
     mentions: JSONType,
-) -> Dict[str, Dict[str, int]]:
-    languages: Dict[str, Dict[str, int]] = {}
+) -> dict[str, dict[str, int]]:
+    languages: dict[str, dict[str, int]] = {}
     for nutrient, matches in mentions.items():
-        seen_lang: Set[str] = set()
+        seen_lang: set[str] = set()
 
         for match in matches:
             for lang in match.get("languages", []):
